# `chromatic`

The `chromatic-lightcurves` package is a friendly python tool for working with spectroscopic light curves. Inspired by the [`lightkurve`](https://docs.lightkurve.org/) package, we aim for this tool to provide an easy way interact with datasets representing the brightness of a star as a function of both time and wavelength.

This package defines a spectroscopic light curve object (a `Rainbow` = 🌈) to provide easy access to wavelength, time, flux, and uncertainty attributes. It allows reading and writing these datasets from/to a variety of formats, simplifies many common calculations, and provides a plethora of visualizations. Read on for quick introductions to how these little 🌈s work!
